@@ -35,7 +35,7 @@ EVAL_COMMAND_NAME = 'ep2_eval'
 KEY_UE_NO = 'ue'
 KEY_UE_TAG = 'tag'
 
-__version__ = '0.4.11'
+__version__ = '0.4.15'
 
 def relative_path(basedir, filename):
     """Creates a path relative to base"""
@@ -185,7 +185,10 @@ class Ep2Group:
 
     def exercise_test_csv(self, ue):
         """Creates the path to the adhoc submission CSV file for an exercise for a group"""
-        return os.path.join(self.ep2.tutor_repo(), self.name, "ex_test_" + str(ue) + ".csv")
+        if ue_type(ue) == ExerciseType.Normal:
+            return os.path.join(self.ep2.tutor_repo(), self.name, "ex_test_" + str(ue) + ".csv")
+        else:
+            return os.path.join(self.ep2.tutor_repo(), self.name, "ex_test_ta.csv")
 
     def attendance_csv(self, ue: int):
         """Creates the path to the attendance CSV file for an exercise for a group"""
@@ -357,7 +360,10 @@ class Ep2:
         return os.path.join(self.config.get('Local', 'GitHome'), 'uebung', mat_no)
 
     def ex_test_repo_name(self, mat_no: str, ue: int):
-        return '{}u{}'.format(mat_no, ue)
+        if ex_test_type(ue) == ExTestType.Single:
+            return '{}u{}'.format(mat_no, ue)
+        else:
+            return mat_no
 
     def local_ex_test_repo(self, mat_no: str, ue: int):
         """Returns the local path of students uebungs repo"""
@@ -587,12 +593,7 @@ class Ep2:
         return True, grading
 
     def exercise_test_repo(self, ex: int, student_id: str) -> Optional[str]:
-        ex_type = ex_test_type(ex)
-
-        if ex_type == ExTestType.Single:
-            return os.path.join(self.config.get("Gitlab", "RepoPrefix"), 'uebung', self.ex_test_repo_name(student_id, ex)).replace("\\", "/")
-        else:
-            return None
+        return os.path.join(self.config.get("Gitlab", "RepoPrefix"), 'uebung', self.ex_test_repo_name(student_id, ex)).replace("\\", "/")
 
     def grant_access(self, project_path: str, student_id: str) -> Result[None, str]:
         """ Grants maintainer access for `student_id` to the project at `project_path`.
